@@ -32,7 +32,7 @@ package Net::Shadowsocks::Client;
     use Socket qw(IPPROTO_TCP MSG_FASTOPEN SOL_SOCKET SO_REUSEPORT SO_REUSEADDR);
     #use String::HexConvert ':all';
     
-    our $VERSION = '0.9.3.2';
+    our $VERSION = '0.9.3.3';
     $AnyEvent::Log::FILTER->level ("info");
     sub new($$$$$$) 
     {
@@ -608,13 +608,9 @@ Project website https://osdn.net/projects/ssperl/
 
 =head2 new
 
-    The C<new> constructor lets you create a new B<Net::Shadowsocks::Client> object.
+    The new constructor lets you create a new Net::Shadowsocks::Client object or dies on error.
 
-    So no big surprises there...
-
-    Returns a new B<Net::Shadowsocks::Client> or dies on error.
-
-    example use:
+    Example use:
 
     my $foo = Net::Shadowsocks::Client->new(
     local_address => 'localhost',
