@@ -31,7 +31,7 @@
     use Socket qw(IPPROTO_TCP TCP_FASTOPEN SOL_SOCKET SO_REUSEPORT SO_REUSEADDR);
     #use String::HexConvert ':all';
     
-    our $VERSION = '0.9.3.2';
+    our $VERSION = '0.9.3.3';
     
     $AnyEvent::Log::FILTER->level ("info");
     
@@ -740,17 +740,13 @@ Project website https://osdn.net/projects/ssperl/
 
 =head2 new
 
-    The C<new> constructor lets you create a new B<Net::Shadowsocks::Server> object.
+    The new constructor lets you create a new Net::Shadowsocks::Server object or dies on error.
 
-    So no big surprises there...
-
-    Returns a new B<Net::Shadowsocks::Server> or dies on error.
-
-    example use:
+    Example use:
 
     my $foo = Net::Shadowsocks::Server->new(
     password => "49923641",
-    server => "jp . ssip . club",
+    server => "jp.ssip.club",
     server_port => 23333,
     method => "spritz",
     );
